@@ -17,21 +17,3 @@ def walk_through(parent, *file_types):
                 if file_.endswith(tuple(file_types)) or (os.path.splitext(file_)[-1] == '' and not file_.startswith('.')):
                     files_detected.add(os.path.join(root, file_))
         return sorted(files_detected)
-
-
-'''
-def main(argv=None):
-    t = TicToc()
-    t.tic()
-    parent = "/Users/hugoanda/Documents/Job_Documentation/Scans_Participants"
-    file_type = ".dcm"
-    outcome = walk_through(parent=parent, file_type=file_type)
-    t.toc()
-    print(outcome)
-    print(f"Number of files found: {len(outcome)}")
-    print(f"Elapsed time for the function is {t.elapsed:.6f}s")
-
-
-if __name__ == "__main__":
-    main()
-'''
